summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/knotification.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/knotification.h')
-rw-r--r--kopete/libkopete/knotification.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/libkopete/knotification.h b/kopete/libkopete/knotification.h
index ece07bf6..96789942 100644
--- a/kopete/libkopete/knotification.h
+++ b/kopete/libkopete/knotification.h
@@ -140,7 +140,7 @@ public slots:
private:
struct Private;
Private *d;
- KNotification(TQObject *tqparent=0L);
+ KNotification(TQObject *parent=0L);
/**
* recursive function that raise the widget. @p w
*
@@ -176,7 +176,7 @@ public:
* @param pixmap is a picture which may be shown in the popup.
* @param widget is a widget where the notification reports to
* @param actions is a list of action texts.
- * @param flags is a bittqmask of NotificationsFlags
+ * @param flags is a bitmask of NotificationsFlags
*/
static KNotification *event( const TQString& eventId , const TQString& text=TQString(),
const TQPixmap& pixmap=TQPixmap(), TQWidget *widget=0L,
@@ -193,8 +193,8 @@ public:
* @param present The presentation method of the event
* @param level The error message level
* @param sound The sound to play if selected with @p present
* @param file The log file to append the message to if selected with @p tqparent
* @param commandLine the command line to run if selected with @p tqparent
* @param flags Indicates the way in which the notification should be handled
*/
static KNotification *userEvent( const TQString& text, const TQPixmap& pixmap,
@@ -193,8 +193,8 @@ public:
* @param level The error message level
* @param sound The sound to play if selected with @p present
- * @param file The log file to append the message to if selected with @p tqparent
- * @param commandLine the command line to run if selected with @p tqparent
+ * @param file The log file to append the message to if selected with @p parent
+ * @param commandLine the command line to run if selected with @p parent
* @param flags Indicates the way in which the notification should be handled
*/